@@ -44,8 +44,8 @@ class URL(click.ParamType):
     show_default=True,
     type=URL(),
 )
-@click.option("--username", default="shughes-nn")
-@click.option("--password", default="_67TY9V4rMb7egVPWaJn", hide_input=True)
+@click.option("--username", prompt="NND Username")
+@click.option("--password", prompt=True, hide_input=True)
 def login(profile, nomitall_url, username, password):
     base_url = nomitall_url.netloc
 
